
# Pyqrlew core

```{eval-rst}
.. autoclass:: pyqrlew.Dataset()
    :members:
```

```{eval-rst}
.. autoclass:: pyqrlew.Relation()
    :members:
```

```{eval-rst}
.. autoclass:: pyqrlew.RelationWithDpEvent
    :members:
```

```{eval-rst}
.. autoclass:: pyqrlew.DpEvent
    :members:
```

```{eval-rst}
.. autoclass:: pyqrlew.Dialect
    :members:
    :undoc-members:
```

```{eval-rst}
.. autoclass:: pyqrlew.Strategy
    :members:
    :undoc-members:
```